@@ -155,6 +155,8 @@ def test_styles_file(processes):
     }
     assert style_dict['glyphs'] == \
         'http://127.0.0.1:8080/v1/fonts/fonts-gl@1.0.0/{fontstack}/{range}.pbf'
+    assert style_dict['sprite'] == \
+        'http://127.0.0.1:8080/v1/styles/positron-gl-style@1.0.0/sprite'
 
 
 def test_styles_file_x_forwarded(processes):
@@ -180,31 +182,84 @@ def test_styles_file_x_forwarded(processes):
     }
     assert style_dict['glyphs'] == \
         'https://www.mypublicdomain.com/v1/fonts/fonts-gl@1.0.0/{fontstack}/{range}.pbf'
+    assert style_dict['sprite'] == \
+        'https://www.mypublicdomain.com/v1/styles/positron-gl-style@1.0.0/sprite'
+
+
+def test_sprites_exists(processes):
+    urls = (
+        'http://127.0.0.1:8080/v1/styles/positron-gl-style@1.0.0/sprite.json',
+        'http://127.0.0.1:8080/v1/styles/positron-gl-style@1.0.0/sprite@2x.json',
+        'http://127.0.0.1:8080/v1/styles/positron-gl-style@1.0.0/sprite.png',
+        'http://127.0.0.1:8080/v1/styles/positron-gl-style@1.0.0/sprite@2x.png',
+    )
+
+    for url in urls:
+        response = httpx.get(url)
+        response.raise_for_status()
+        assert response.status_code == 200
+        assert len(response.content) > 10
+
+
+def test_sprites_not_exist(processes):
+    urls = (
+        'http://127.0.0.1:8080/v1/styles/positron-gl-style@2.0.0/sprite.json',
+        'http://127.0.0.1:8080/v1/styles/positron-gl-style@1.0.0/sprite@3x.png',
+        'http://127.0.0.1:8080/v1/styles/maptiler-basic-gl-style@1.0.0/sprite.json',
+        'http://127.0.0.1:8080/v1/styles/another-one@1.0.0/sprite.json',
+    )
+
+    for url in urls:
+        response = httpx.get(url)
+        assert response.status_code == 404
 
 
 def test_styles_file_does_not_exists(processes):
     response = httpx.get(
         'http://127.0.0.1:8080/v1/styles'
-        '/positron-gl-style@1.0.0/notmystyle.json?tiles=mytiles@1.1')
+        '/positron-gl-style@1.0.0/notmystyle.json?fonts=fonts-gl&tiles=mytiles@1.1')
     assert response.status_code == 404
 
 
 def test_styles_file_without_tiles_argument(processes):
     response = httpx.get(
-        'http://127.0.0.1:8080/v1/styles/positron-gl-style@1.0.0/style.json')
+        'http://127.0.0.1:8080/v1/styles/'
+        'positron-gl-style@1.0.0/style.json?fonts=fonts-gl@1.0.0')
     assert response.status_code == 400
 
 
 def test_styles_file_without_tiles_version(processes):
     response = httpx.get(
-        'http://127.0.0.1:8080/v1/styles/positron-gl-style@1.0.0/style.json?tiles=mytiles')
+        'http://127.0.0.1:8080/v1/styles/'
+        'positron-gl-style@1.0.0/style.json?fonts=fonts-gl@1.0.0&tiles=mytiles')
     assert response.status_code == 400
 
 
 def test_styles_file_with_tiles_that_does_not_exists(processes):
     response = httpx.get(
         'http://127.0.0.1:8080/v1/styles'
-        '/positron-gl-style@1.0.0/style.json?tiles=notmytiles@1.1')
+        '/positron-gl-style@1.0.0/style.json?fonts=fonts-gl@1.0.0&tiles=notmytiles@1.1')
+    assert response.status_code == 404
+
+
+def test_styles_file_without_fonts_argument(processes):
+    response = httpx.get(
+        'http://127.0.0.1:8080/v1/styles/'
+        'positron-gl-style@1.0.0/style.json?tiles=mytiles@1.1')
+    assert response.status_code == 400
+
+
+def test_styles_file_without_fonts_version(processes):
+    response = httpx.get(
+        'http://127.0.0.1:8080/v1/styles/'
+        'positron-gl-style@1.0.0/style.json?fonts=fonts-gl&tiles=mytiles@1.1')
+    assert response.status_code == 400
+
+
+def test_styles_file_with_fonts_that_does_not_exists(processes):
+    response = httpx.get(
+        'http://127.0.0.1:8080/v1/styles'
+        '/positron-gl-style@1.0.0/style.json?fonts=not-exists@1.0.0&tiles=mytiles@1.1')
     assert response.status_code == 404
 
 
@@ -235,6 +290,36 @@ def test_font_files(processes):
     assert len(response.content) > 1000
 
 
+def test_font_pack_that_does_not_exist(processes):
+    response = httpx.get(
+        'http://127.0.0.1:8080/v1/fonts/not-exist@1.0.0/Metropolis Regular/0-255.pbf')
+    assert response.status_code == 404
+
+
+def test_font_that_does_not_exist(processes):
+    response = httpx.get(
+        'http://127.0.0.1:8080/v1/fonts/fonts-gl@1.0.0/Jane/0-255.pbf')
+    assert response.status_code == 404
+
+
+def test_font_file_that_does_not_exist(processes):
+    response = httpx.get(
+        'http://127.0.0.1:8080/v1/fonts/fonts-gl@1.0.0/Metropolis Regular/0-254.pbf')
+    assert response.status_code == 404
+
+
+def test_font_file_that_does_not_exist_with_dot(processes):
+    response = httpx.get(
+        'http://127.0.0.1:8080/v1/fonts/fonts-gl@1.0.0/Metropolis..Regular/0-255.pbf')
+    assert response.status_code == 404
+
+
+def test_font_file_range_that_does_not_exist_with_dot(processes):
+    response = httpx.get(
+        'http://127.0.0.1:8080/v1/fonts/fonts-gl@1.0.0/Metropolis..Regular/0-..255.pbf')
+    assert response.status_code == 404
+
+
 def put_object_no_raise(key, contents, params=()):
     url = f'http://127.0.0.1:9000/my-bucket/{key}'
     body_hash = hashlib.sha256(contents).hexdigest()
